@@ -11,16 +11,16 @@ context("ISOIdentifier")
 test_that("encoding",{
   
   #encoding
-  md <- ISOIdentifier$new(code = "identifier", prefix = "MD")
+  md <- ISOIdentifier$new(code = "identifier")
   expect_is(md, "ISOIdentifier")
   expect_equal(md$code, "identifier")
-  xml <- md$encode()
+  xml <- md$encode(validate=F)
   expect_is(xml, "XMLInternalNode")
   
   #decoding
-  md2 <- ISOIdentifier$new(xml = xml, prefix = "MD")
-  xml2 <- md2$encode()
+  md2 <- ISOIdentifier$new(xml = xml)
+  xml2 <- md2$encode(validate=F)
   
-  expect_true(ISOMetadataElement$compare(md, md2))
+  expect_true(ISOAbstractObject$compare(md, md2))
   
 })
\ No newline at end of file
